import React, { CSSProperties, FC, ForwardedRef, ForwardRefRenderFunction, ReactElement, RefObject } from 'react';
import { VariableSizeGridProps } from 'react-window';
import { ChildGroup, Item, ItemMap, RowMap } from './timeline-data';
export declare type BodyRenderer = ForwardRefRenderFunction<HTMLElement, BodyRendererProps>;
export interface BodyRendererProps {
    style: CSSProperties;
    ref: ForwardedRef<HTMLDivElement>;
}
export declare type ItemRenderer<T extends Item = Item> = FC<ItemRendererProps<T>>;
export interface ItemRendererProps<T extends Item = Item> {
    item: T;
    style: CSSProperties;
}
export declare type GroupRenderer = FC<GroupRendererProps>;
export interface GroupRendererProps {
    group: ChildGroup;
    isEven: boolean;
    isOdd: boolean;
    isParentGroup: boolean;
    rowIndex: number;
    style: CSSProperties;
}
export declare type TimebarIntervalRenderer = FC<TimebarIntervalRendererProps>;
export interface TimebarIntervalRendererProps {
    time: number;
    isOdd: boolean;
    isEven: boolean;
    isDay: boolean;
    style: CSSProperties;
}
export declare type RowRenderer = FC<RowRendererProps>;
export interface RowRendererProps {
    group: ChildGroup;
    isEven: boolean;
    isOdd: boolean;
    rowIndex: number;
    style: CSSProperties;
}
export declare type ColumnRenderer = FC<ColumnRendererProps>;
export declare type ColumnRendererProps = Omit<TimebarIntervalRendererProps, 'isDay'>;
export declare type TimebarHeaderRenderer = FC<TimebarHeaderProps>;
export interface TimebarHeaderProps {
    style: CSSProperties;
}
export declare type SidebarHeaderRenderer = FC<SidebarHeaderRendererProps>;
export interface SidebarHeaderRendererProps {
    style: CSSProperties;
}
export declare type SidebarRenderer = FC<SidebarRendererProps>;
export interface SidebarRendererProps {
    style: CSSProperties;
}
export declare type UpsertItem<T extends Item = Item> = (item: T) => void;
export declare type RemoveItem<T extends Item = Item> = (item: T) => void;
export declare enum UpdateItemAction {
    MOVE = 0,
    RESIZE = 1
}
export declare type GetUpdatedItem = (event: React.MouseEvent<HTMLElement, MouseEvent>, item: Item, options: {
    action?: UpdateItemAction;
    snapToRow?: boolean;
}) => null | Item;
export declare type CreateItemAtCursor = (event: React.MouseEvent<HTMLElement, MouseEvent>, defaultValues: Partial<Item> & {
    id: Item['id'];
    duration: number;
    defaultGroupId?: ChildGroup['id'];
}) => null | {
    start: number;
    end: number;
    groupId?: string;
};
export interface TimelineContextValue {
    BodyRenderer: BodyRenderer;
    ColumnRenderer?: ColumnRenderer;
    GroupRenderer?: GroupRenderer;
    ItemRenderer: ItemRenderer<any>;
    RowRenderer?: RowRenderer;
    SidebarHeaderRenderer: SidebarHeaderRenderer;
    SidebarRenderer: SidebarRenderer;
    TimebarHeaderRenderer?: TimebarHeaderRenderer;
    TimebarIntervalRenderer?: TimebarIntervalRenderer;
    children?: ReactElement | null;
    columnCount: number;
    columnWidth: VariableSizeGridProps['columnWidth'];
    createItemAtCursor: CreateItemAtCursor;
    endTime: number;
    getUpdatedItem: GetUpdatedItem;
    height: number;
    intervalDuration: number;
    intervalWidth: number;
    intervals: number[];
    itemData: any;
    itemHeight: number;
    itemMap: ItemMap;
    minItemWidth: number;
    outerRef: RefObject<HTMLDivElement>;
    overscanColumnStartIndex: number;
    overscanColumnStopIndex: number;
    overscanRowStartIndex: number;
    overscanRowStopIndex: number;
    removeItem: RemoveItem;
    rowCount: number;
    rowHeight: VariableSizeGridProps['rowHeight'];
    rowMap: RowMap;
    setStickyItemIds: (items: Array<Item['id']>) => void;
    collectionSidebarWidth: number;
    groupSidebarWidth: number;
    snapDuration: number;
    startTime: number;
    stickyItemIds: Array<Item['id']>;
    timebarHeaderHeight: number;
    timebarIntervalHeight: number;
    upsertItem: UpsertItem;
    visibleColumnStartIndex: number;
    visibleColumnStopIndex: number;
    visibleRowStartIndex: number;
    visibleRowStopIndex: number;
    width: number;
}
declare const TimelineContext: React.Context<TimelineContextValue>;
export default TimelineContext;
